@@ -417,7 +417,7 @@ class _SignedPoster:
         if isinstance(rval, str) and len(rval) == 64 and self.url.split("/")[-1] == "new-db" and "db_id" in kwargs:
             dbid = kwargs["db_id"]
             while True:
-                databases = await self.client.dbs()
+                databases = await self.client.ledgers()
                 for database in databases:
                     dbid2 = database[0] + "/" + database[1]
                     if dbid == dbid2:
@@ -592,24 +592,40 @@ class FlureeClient:
                                     "delete_db",
                                     "add_server",
                                     "remove_server",
+                                    "ledgers",
+                                    "new_ledger",
+                                    "delete_ledger",
                                     "health",
                                     "new_keys",
                                     "sub",
                                     "nw_state",
                                     "version"])
-        self.unsigned_endpoints = set(["dbs", "health", "new_keys", "nw_state", "version"])
+        self.depricated = {
+                    "dbs": "ledgers",
+                    "new_db": "new_ledger",
+                    "delete_db": "delete_ledger",
+                    "add_server": None,
+                    "remove_server": None
+                }
+        self.unsigned_endpoints = set(["dbs","ledgers","health", "new_keys", "nw_state", "version"])
         self.use_get = set(["health", "new_keys", "nw_state", "version"])
         self.required = {}
         self.required["new_db"] = set(["db_id"])
+        self.required["new_ledger"] = set(["db_id"])
         self.required["delete_db"] = set(["db_id"])
+        self.required["delete_ledger"] = set(["db_id"])
         self.required["add_server"] = set(["server"])
         self.required["delete_server"] = set(["server"])
         self.optional = {"new_db": set(["snapshot"])}
+        self.optional = {"new_ledger": set(["snapshot"])}
         self.implemented = set(["dbs",
+                                "ledgers",
                                 "new_keys",
                                 "health",
                                 "new_db",
+                                "new_ledger",
                                 "delete_db",
+                                "delete_ledger",
                                 "add_server",
                                 "remove_server",
                                 "nw_state",
@@ -669,6 +685,8 @@ class FlureeClient:
             raise AttributeError("FlureeDB has no endpoint named " + api_endpoint)
         if api_endpoint not in self.implemented:
             raise NotImplementedError("No implementation yet for " + api_endpoint)
+        if api_endpoint in self.depricated and self.depricated[api_endpoint] is not None:
+            api_endpoint = self.depricated[api_endpoint]
         secure = ""
         if self.https:
             secure = "s"
@@ -723,7 +741,7 @@ class FlureeClient:
             parts = key.split("/")
             key = parts[0]
             subkey = parts[1]
-        databases = await self.dbs()
+        databases = await self.ledgers()
         options = set()
         for pair in databases:
             if pair[0] == key:
@@ -745,7 +763,7 @@ class FlureeClient:
         _Network
             Itteratable object with databases per network.
         """
-        databases = await self.dbs()
+        databases = await self.ledgers()
         optionsmap = {}
         for pair in databases:
             network = pair[0]
