@@ -372,7 +372,7 @@ class _Transformer:
         rval = self.jsonatacontext(self.xform, query_result)
         if rval == 'undefined':
             return None
-        return json.loads(rval)
+        return rval
 
 
 class _TemplateCollection:
@@ -466,7 +466,7 @@ class _TemplateCollection:
                     try:
                         with open(xform_path) as xform_file:
                             if AIOFLUREEDB_HAS_JSONATA or deep_fail:
-                                self.xform[template] = xform_file.read()
+                                self.xform[template] = xform_file.read().rstrip("\r\n")
                             elif not ignore_xform:
                                 raise RuntimeError(
                                     "API-Map uses jsonata transformation files while pyjsonata module is not available."
